@@ -39,8 +39,10 @@ from lightbulb import errors
 from lightbulb import events
 from lightbulb import help as help_
 from lightbulb import plugins
+from lightbulb import slash_commands
 from lightbulb.converters import _DefaultingConverter
 from lightbulb.converters import _GreedyConverter
+from lightbulb.slash_commands.commands import _serialise_command
 from lightbulb.utils import maybe_await
 
 _LOGGER = logging.getLogger("lightbulb")
@@ -48,8 +50,32 @@ _LOGGER = logging.getLogger("lightbulb")
 # XXX: can't we use `str.split()` here, which splits on all whitespace in the same way?
 ARG_SEP_REGEX = re.compile(r"(?:\s+|\n)")
 
+prefix_T = typing.Union[
+    str,
+    typing.Iterable[str],
+    typing.Callable[
+        ["Bot", hikari.Message],
+        typing.Union[
+            typing.Coroutine[None, None, typing.Union[str, typing.Iterable[str]]],
+            typing.Union[str, typing.Iterable[str]],
+        ],
+    ],
+]
 
-def when_mentioned_or(prefix_provider):
+
+class _ExtensionType(typing.Protocol):
+    @staticmethod
+    def load(bot: Bot) -> None:
+        ...
+
+    @staticmethod
+    def unload(bot: Bot) -> None:
+        ...
+
+
+def when_mentioned_or(
+    prefix_provider: prefix_T,
+) -> typing.Callable[[Bot, hikari.Message], typing.Coroutine[None, None, typing.Iterable[str]]]:
     """
     Helper function which allows the bot's mentions to be used as the command prefix, as well
     as any other prefix(es) passed in or supplied by the ``prefix_provider``.
@@ -78,7 +104,7 @@ def when_mentioned_or(prefix_provider):
     """
 
     async def get_prefixes(bot, message):
-        mentions = [f"<@{bot.me.id}> ", f"<@!{bot.me.id}> "]
+        mentions = [f"<@{bot.get_me().id}> ", f"<@!{bot.get_me().id}> "]
 
         if callable(prefix_provider):
             prefixes = prefix_provider(bot, message)
@@ -107,7 +133,7 @@ def _return_prefix(_: typing.Any, __: typing.Any, *, prefixes: typing.Iterable[s
 
 class Bot(hikari.GatewayBot):
     """
-    A subclassed implementation of :class:`hikari.impl.bot.BotAppImpl` which contains a command handler.
+    A subclassed implementation of :class:`hikari.impl.bot.GatewayBot` which contains a command handler.
     This should be instantiated instead of the superclass if you want to be able to use
     the command handler implementation provided.
 
@@ -130,21 +156,42 @@ class Bot(hikari.GatewayBot):
         help_class (:obj:`~.help.HelpCommand`): The **uninstantiated** class the bot should use for it's help command.
             Defaults to :obj:`~.help.HelpCommand`. Any class passed should always be this class or subclass of
             this class.
-        **kwargs: Other parameters passed to the :class:`hikari.impl.bot.BotAppImpl` constructor.
+        delete_unbound_slash_commands (:obj:`bool`): Whether or not to delete unbound slash commands when the
+            bot starts. This will remove any slash commands that do not have a
+            :obj:`~lightbulb.slash_commands.SlashCommand` object bound to them when the bot starts but are registered
+            according to  discord's API. Defaults to ``True``.
+        recreate_changed_slash_commands (:obj:`bool`): Whether or not to send the new version of the slash command
+            to discord if the bot detects that the version on discord does not match the local version. Defaults
+            to ``True``.
+        slash_commands_only (:obj:`bool`): Whether or not the bot will only be using slash commands to interact
+            with discord. Defaults to ``False``. If this is ``False`` and no prefix is provided then an error will
+            be raised. If ``True``, then you do not need to provide a prefix.
+        **kwargs: Other parameters passed to the :class:`hikari.impl.bot.GatewayBot` constructor.
     """
 
     def __init__(
         self,
+        token: str,
         *,
-        prefix,
+        prefix: prefix_T = None,
         insensitive_commands: bool = False,
         ignore_bots: bool = True,
         owner_ids: typing.Iterable[int] = (),
         help_class: typing.Type[help_.HelpCommand] = help_.HelpCommand,
+        delete_unbound_slash_commands: bool = True,
+        recreate_changed_slash_commands: bool = True,
+        slash_commands_only: bool = False,
         **kwargs,
     ) -> None:
-        super().__init__(**kwargs)
-        self.subscribe(hikari.MessageCreateEvent, self.handle)
+        super().__init__(token, **kwargs)
+
+        if prefix is None and slash_commands_only is False:
+            raise TypeError("slash_commands_only is False but no prefix was provided.")
+
+        if not slash_commands_only:
+            self.subscribe(hikari.MessageCreateEvent, self.handle)
+        self.subscribe(hikari.InteractionCreateEvent, self.handle_slash_commands)
+        self.subscribe(hikari.StartingEvent, self._manage_slash_commands)
 
         if isinstance(prefix, str):
             self.get_prefix = functools.partial(_return_prefix, prefixes=[prefix])
@@ -168,21 +215,33 @@ class Bot(hikari.GatewayBot):
         """A set containing all commands and groups registered to the bot."""
         self._checks = []
 
+        self._delete_unbound_slash_commands = delete_unbound_slash_commands
+        self._recreate_changed_slash_commands = recreate_changed_slash_commands
+        self._slash_commands: typing.MutableMapping[
+            str, typing.Union[slash_commands.SlashCommand, slash_commands.SlashCommandGroup]
+        ] = {}
+        self.slash_commands: typing.Set[
+            typing.Union[slash_commands.SlashCommand, slash_commands.SlashCommandGroup]
+        ] = set()
+        """A set containing all slash commands registered to the bot."""
+
+        self._app: typing.Optional[hikari.PartialApplication] = None
+
         self._help_impl = help_class(self)
 
     @staticmethod
     def print_banner(banner: typing.Optional[str], allow_color: bool, force_color: bool) -> None:
         ux.print_banner(banner, allow_color, force_color)
         if banner == "hikari":
-            sys.stdout.write(f"Thank you for using lightbulb!\n")
+            sys.stdout.write("Thank you for using lightbulb!\n")
 
     @property
-    def help_command(self):
+    def help_command(self) -> help_.HelpCommand:
         """The instance of the help class used by the bot."""
         return self._help_impl
 
     @help_command.setter
-    def help_command(self, new_help_instance: help_.HelpCommand):
+    def help_command(self, new_help_instance: help_.HelpCommand) -> None:
         self._help_impl = new_help_instance
 
     async def fetch_owner_ids(self) -> None:
@@ -326,16 +385,16 @@ class Bot(hikari.GatewayBot):
             if set([name.casefold() for name in self._commands.keys()]).intersection(
                 {func.name.casefold(), *[a.casefold() for a in func._aliases]}
             ):
-                raise NameError(f"Command {func.name} has name or alias already registered.")
+                raise NameError(f"Command {func.name!r} has name or alias already registered.")
         else:
             if set(self._commands.keys()).intersection({func.name, *func._aliases}):
-                raise NameError(f"Command {func.name} has name or alias already registered.")
+                raise NameError(f"Command {func.name!r} has name or alias already registered.")
 
         self.commands.add(func)
         self._commands[func.name] = func
         for alias in func._aliases:
             self._commands[alias] = func
-        _LOGGER.debug("new command registered: %s", func.name)
+        _LOGGER.debug("new command registered %r", func.name)
         return self._commands[func.name]
 
     def add_group(self, func: typing.Union[typing.Callable, commands.Group], **kwargs) -> commands.Group:
@@ -373,13 +432,13 @@ class Bot(hikari.GatewayBot):
             )
 
         if set(self._commands.keys()).intersection({func.name, *func._aliases}):
-            raise AttributeError(f"Command {func.name} has name or alias already registered.")
+            raise AttributeError(f"Command {func.name!r} has name or alias already registered.")
 
         self.commands.add(func)
         self._commands[func.name] = func
         for alias in func._aliases:
             self._commands[alias] = func
-        _LOGGER.debug("new group registered: %s", func.name)
+        _LOGGER.debug("new group registered %r", func.name)
         return self._commands[func.name]
 
     def add_check(self, func: typing.Callable[[context_.Context], typing.Coroutine[None, None, bool]]) -> None:
@@ -397,12 +456,16 @@ class Bot(hikari.GatewayBot):
         """
         self._checks.append(func)
 
-    def add_plugin(self, plugin: plugins.Plugin) -> None:
+    def add_plugin(self, plugin: typing.Union[plugins.Plugin, typing.Type[plugins.Plugin]]) -> None:
         """
-        Add a :obj:`~.plugins.Plugin` to the bot including all of the plugin commands.
+        Add a :obj:`~.plugins.Plugin` instance or class to the bot, including all of the plugin commands.
+
+        If a class is passed in instead of a plugin instance, then the bot will attempt to instantiate it and
+        then add the newly-created plugin instance to the bot.
 
         Args:
-            plugin (:obj:`~.plugins.Plugin`): Plugin to add to the bot.
+            plugin (Union[:obj:`~.plugins.Plugin`, Type[:obj:`~.plugins.Plugin`]]): Plugin instance or plugin
+                subclass to add to the bot.
 
         Returns:
             ``None``
@@ -411,8 +474,11 @@ class Bot(hikari.GatewayBot):
             :obj:`NameError`: If the name of the plugin being added conflicts with an
                 existing plugin.
         """
+        if inspect.isclass(plugin) and issubclass(plugin, plugins.Plugin):
+            return self.add_plugin(plugin())
+
         if plugin.name in self.plugins:
-            raise NameError(f"A plugin named {plugin.name} is already registered.")
+            raise NameError(f"A plugin named {plugin.name!r} is already registered.")
 
         self.plugins[plugin.name] = plugin
         for command in plugin._commands.values():
@@ -425,9 +491,9 @@ class Bot(hikari.GatewayBot):
             for listener in listeners:
                 callback = listener.__get__(plugin, type(plugin))
                 self.subscribe(listener.event_type, callback)
-                _LOGGER.debug("new listener registered: %s (%s)", callback.__name__, listener.event_type.__name__)
+                _LOGGER.debug("new listener registered %r (%s)", callback.__name__, listener.event_type.__name__)
 
-        _LOGGER.debug("new plugin registered: %s", plugin.name)
+        _LOGGER.debug("new plugin registered %r", plugin.name)
 
     def get_command(self, name: str) -> typing.Optional[commands.Command]:
         """
@@ -485,7 +551,7 @@ class Bot(hikari.GatewayBot):
         keys_to_remove.remove(name)
         for key in keys_to_remove:
             self._commands.pop(key)
-        _LOGGER.debug("command removed: %s", command.name)
+        _LOGGER.debug("command removed %r", command.name)
 
         return command.name
 
@@ -513,9 +579,9 @@ class Bot(hikari.GatewayBot):
             for listener in listeners:
                 callback = listener.__get__(plugin, type(plugin))
                 self.unsubscribe(listener.event_type, callback)
-                _LOGGER.debug("listener removed: %s (%s)", callback.__name__, listener.event_type.__name__)
+                _LOGGER.debug("listener removed %r (%s)", callback.__name__, listener.event_type.__name__)
 
-        _LOGGER.debug("plugin removed: %s", plugin.name)
+        _LOGGER.debug("plugin removed %r", plugin.name)
 
         return plugin.name
 
@@ -551,16 +617,17 @@ class Bot(hikari.GatewayBot):
                     bot.add_plugin(MyPlugin())
         """
         if extension in self.extensions:
-            raise errors.ExtensionAlreadyLoaded(text=f"{extension} is already loaded.")
+            raise errors.ExtensionAlreadyLoaded(text=f"Extension {extension!r} is already loaded.")
 
         module = importlib.import_module(extension)
+        module = typing.cast(_ExtensionType, module)
 
         if not hasattr(module, "load"):
-            raise errors.ExtensionMissingLoad(text=f"{extension} is missing a load function")
+            raise errors.ExtensionMissingLoad(text=f"Extension {extension!r} is missing a load function")
         else:
             module.load(self)
             self.extensions.append(extension)
-            _LOGGER.debug("new extension loaded: %s", extension)
+            _LOGGER.debug("new extension loaded %r", extension)
 
     def unload_extension(self, extension: str) -> None:
         """
@@ -594,17 +661,18 @@ class Bot(hikari.GatewayBot):
                     bot.remove_plugin("MyPlugin")
         """
         if extension not in self.extensions:
-            raise errors.ExtensionNotLoaded(text=f"{extension} is not loaded.")
+            raise errors.ExtensionNotLoaded(text=f"Extension {extension!r} is not loaded.")
 
         module = importlib.import_module(extension)
+        module = typing.cast(_ExtensionType, module)
 
         if not hasattr(module, "unload"):
-            raise errors.ExtensionMissingUnload(text=f"{extension} is missing an unload function")
+            raise errors.ExtensionMissingUnload(text=f"Extension {extension!r} is missing an unload function")
         else:
             module.unload(self)
             self.extensions.remove(extension)
             del sys.modules[extension]
-            _LOGGER.debug("extension unloaded: %s", extension)
+            _LOGGER.debug("extension unloaded %r", extension)
 
     def reload_extension(self, extension: str) -> None:
         """
@@ -618,7 +686,7 @@ class Bot(hikari.GatewayBot):
         Returns:
             ``None``
         """
-        _LOGGER.debug("reloading extension: %s", extension)
+        _LOGGER.debug("reloading extension %r", extension)
         old = sys.modules[extension]
         try:
             self.unload_extension(extension)
@@ -684,6 +752,25 @@ class Bot(hikari.GatewayBot):
         """
         return context_.Context(self, message, prefix, invoked_with, invoked_command)
 
+    def get_slash_command_context(
+        self,
+        event: hikari.InteractionCreateEvent,
+        command: typing.Union[slash_commands.SlashCommand, slash_commands.SlashCommandGroup],
+    ) -> slash_commands.SlashCommandContext:
+        """
+        Get the :obj:`~.slash_commands.SlashCommandContext` instance for the given arguments. This should be overridden
+        if you wish to supply a custom :obj:`~.slash_commands.SlashCommandContext` class to your slash commands.
+
+        Args:
+            event (:obj:`hikari.InteractionCreateEvent`): The event this context is for.
+            command (Union[:obj:`~.slash_commands.SlashCommand`, :obj:`~.slash_commands.SlashCommandGroup`]): Command
+                invoked for the event.
+
+        Returns:
+            :obj:`~.slash_commands.SlashCommandContext`: Context to use for the command invocation.
+        """
+        return slash_commands.SlashCommandContext(self, event.interaction, command)
+
     async def _evaluate_checks(self, command: commands.Command, context: context_.Context) -> bool:
         checks = [*self._checks, *command.checks]
         if command.plugin is not None:
@@ -739,12 +826,12 @@ class Bot(hikari.GatewayBot):
         if isinstance(prefixes, str):
             prefixes = [prefixes]
 
-        prefix = None
-        for p in prefixes:
-            if message.content.startswith(p):
-                prefix = p
-                break
-        return prefix
+        prefixes.sort(key=len, reverse=True)
+
+        for prefix in prefixes:
+            if message.content.startswith(prefix):
+                return prefix
+        return None
 
     def _validate_command_exists(self, invoked_with) -> commands.Command:
         if (command := self.get_command(invoked_with)) is not None:
@@ -800,7 +887,7 @@ class Bot(hikari.GatewayBot):
             try:
                 conv_out, arg_string = await conv.convert(context, arg_string)
             except (ValueError, TypeError, errors.ConverterFailure):
-                raise errors.ConverterFailure(f"Converting failed for argument: {arg_name}")
+                raise errors.ConverterFailure(f"Converting failed for argument {arg_name!r}")
 
             if isinstance(conv_out, dict):
                 kwargs.update(conv_out)
@@ -882,11 +969,11 @@ class Bot(hikari.GatewayBot):
             await before_invoke(context)
 
         try:
-            positional_args, keyword_arg = await self.resolve_args_for_command(context, command, final_args)
             if not await maybe_await(command._check_exempt_predicate, context):
                 await self._evaluate_checks(command, context)
             else:
-                _LOGGER.debug("Checks bypassed for command: %s", context.message.content)
+                _LOGGER.debug("checks bypassed for command %r", context.message.content)
+            positional_args, keyword_arg = await self.resolve_args_for_command(context, command, final_args)
         except (
             errors.NotEnoughArguments,
             errors.TooManyArguments,
@@ -937,3 +1024,270 @@ class Bot(hikari.GatewayBot):
             return
 
         await self.process_commands_for_event(event)
+
+    def add_slash_command(self, command: typing.Type[slash_commands.BaseSlashCommand], create: bool = False) -> None:
+        """
+        Registers a slash command with the bot.
+
+        Args:
+            command (Type[:obj:`~lightbulb.slash_commands.SlashCommandBase`]): The slash command class to register
+                to the bot. This should **not** be instantiated.
+            create (:obj:`bool`): Whether or not to send a create request to discord when the command is added.
+                Defaults to ``False``.
+
+        Returns:
+            ``None``
+
+        Warning:
+            The ``create`` argument **must** be ``False`` if the command is being added to the bot before
+            the bot has started (i.e. ``bot.run()`` has not yet been called).
+        """
+        cmd = command(self)
+
+        if cmd.name in self._slash_commands:
+            raise NameError(f"Slash command {cmd.name!r} has a name already registered.")
+
+        self._slash_commands[cmd.name] = cmd
+        self.slash_commands.add(cmd)
+
+        if create and self._app is not None:
+            _LOGGER.debug("creating slash command %r", cmd.name)
+            asyncio.create_task(cmd.auto_create(self._app))
+        elif create and self._app is None:
+            _LOGGER.debug("not adding slash command %r as the bot has not started", cmd.name)
+
+        _LOGGER.debug("slash command added %r", cmd.name)
+
+    def remove_slash_command(self, name: str, delete: bool = False) -> typing.Optional[str]:
+        """
+        Remove a slash command from the bot and return its name or ``None`` if no command was removed.
+
+        Args:
+            name (:obj:`str`): The name of the slash command to remove.
+            delete (:obj:`bool`): Whether or not to delete the command from discord when it is removed. Defaults
+                to ``False``.
+
+        Returns:
+            Optional[ :obj:`str` ]: Name of the slash command that was removed.
+        """
+        name = name.lower()
+
+        cmd = self._slash_commands.pop(name)
+        if cmd is not None:
+            self.slash_commands.remove(cmd)
+
+            if delete and self._app is not None:
+                _LOGGER.debug("purging slash command %r", cmd.name)
+                asyncio.create_task(cmd.auto_delete(self._app))
+            elif delete and self._app is None:
+                _LOGGER.debug("not purging slash command %r as the bot has not started", cmd.name)
+
+            _LOGGER.debug("slash command removed %r", cmd.name)
+
+        return cmd.name if cmd is not None else None
+
+    def get_slash_command(
+        self, name: str
+    ) -> typing.Optional[typing.Union[slash_commands.SlashCommand, slash_commands.SlashCommandGroup]]:
+        """
+        Gets the slash command with the given name, or ``None`` if one with that name does
+        not exist.
+
+        Args:
+            name (:obj:`str`): The name of the slash command to get the object for.
+
+        Returns:
+            Optional[:obj:`~lightbulb.slash_commands.BaseSlashCommand`]: Retrieved slash command or ``None``
+                if not found.
+        """
+        return self._slash_commands.get(name)
+
+    async def purge_slash_commands(self, *guild_ids: hikari.Snowflakeish, global_commands: bool = False) -> None:
+        """
+        Purges all slash commands from the guilds with the specified IDs, and all the global slash
+        commands if ``global_commands`` is ``True``. Useful if you want to teardown old slash commands from
+        the bot and cannot be bothered to fetch them individually yourself. If neither `guild_ids` nor `global_commands`
+        is specified then this method will do nothing.
+
+        Args:
+            *guild_ids (:obj:`hikari.Snowflakeish`): IDs for the guilds to purge slash commands from.
+
+        Keyword Args:
+            global_commands (:obj:`bool`): Whether or not to purge global slash commands from the bot.
+
+        Returns:
+            ``None``
+        """
+        commands_to_remove = []
+        if global_commands:
+            commands_to_remove.extend(await self.rest.fetch_application_commands(self._app))
+        if guild_ids:
+            for guild_id in guild_ids:
+                commands_to_remove.extend(await self.rest.fetch_application_commands(self._app, guild_id))
+
+        for command in commands_to_remove:
+            if command.guild_id is None:
+                _LOGGER.debug("deleting global slash command %r", command.name)
+            else:
+                _LOGGER.debug("deleting slash command %r from guild %r", command.name, str(command.guild_id))
+            await command.delete()
+
+    async def handle_slash_commands(self, event: hikari.InteractionCreateEvent) -> None:
+        """
+        The InteractionCreateEvent listener that handles slash command invocations and
+        resolves and invokes the correct callback from the event payload.
+
+        Args:
+            event (:obj:`hikari.InteractionCreateEvent`): The InteractionCreateEvent for the slash command
+                invocation.
+        Returns:
+            ``None``
+        """
+        if not isinstance(event.interaction, hikari.CommandInteraction):
+            return
+
+        command = self.get_slash_command(event.interaction.command_name)
+        if command is None:
+            return
+
+        context = self.get_slash_command_context(event, command)
+        _LOGGER.debug("invoking slash command %r", command.name)
+
+        await self.dispatch(events.SlashCommandInvocationEvent(app=self, command=command, context=context))
+        try:
+            await command(context)
+        except Exception as ex:
+            if not isinstance(ex, errors.CheckFailure):
+                ex = errors.CommandInvocationError(f"{type(ex).__name__}: {ex}", ex)
+
+            error_event = events.SlashCommandErrorEvent(app=self, exception=ex, context=context, command=command)
+
+            handled = False
+            if self.get_listeners(events.SlashCommandErrorEvent, polymorphic=True):
+                await self.dispatch(error_event)
+                handled = True
+
+            if not handled:
+                raise ex
+        else:
+            await self.dispatch(events.SlashCommandCompletionEvent(app=self, command=command, context=context))
+
+    async def _manage_slash_commands(self, _):
+        self._app = await self.rest.fetch_application()
+
+        global_slash_commands = {c.name: c for c in await self.rest.fetch_application_commands(self._app)}
+
+        guilds = set()
+        for cmd in self._slash_commands.values():
+            if cmd.enabled_guilds is not None:
+                guilds.update(cmd.enabled_guilds)
+
+        _guild_slash_commands = {
+            g_id: {c.name: c for c in await self.rest.fetch_application_commands(self._app, g_id)} for g_id in guilds
+        }
+        guild_slash_commands = collections.defaultdict(list)
+        for g_id, cmd_info in _guild_slash_commands.items():
+            for cmd in cmd_info.values():
+                guild_slash_commands[cmd.name].append([cmd, g_id])
+
+        # Note that the purge_slash_commands method is not used here as the bot only purges
+        # commands that appear not to have an implementation registered, as opposed to just
+        # purging every command.
+        remaining_globals = {} if self._delete_unbound_slash_commands is True else global_slash_commands
+        if self._delete_unbound_slash_commands:
+            _LOGGER.debug("purging unbound slash commands")
+            for cmd in global_slash_commands.values():
+                # if an implementation of the slash command is not found
+                if self._slash_commands.get(cmd.name) is None:
+                    _LOGGER.debug("deleting global slash command %r", cmd.name)
+                    await cmd.delete()
+                # if our implementation of the slash command is specific to guilds
+                elif self._slash_commands[cmd.name].enabled_guilds:
+                    _LOGGER.debug("deleting global slash command %r", cmd.name)
+                    await cmd.delete()
+                else:
+                    remaining_globals[cmd.name] = cmd
+
+        remaining_guild_cmds = {}
+        if self._delete_unbound_slash_commands:
+            for cmd_name, cmds in guild_slash_commands.items():
+                for cmd, guild_id in cmds:
+                    # if an implementation of the slash command is not found
+                    if self._slash_commands.get(cmd.name) is None:
+                        _LOGGER.debug("deleting slash command %r from guild %r", cmd.name, str(cmd.guild_id))
+                        await cmd.delete()
+                    # if our implementation of the slash command doesn't contain an entry for this guild
+                    elif cmd.guild_id not in self._slash_commands[cmd.name].enabled_guilds:
+                        _LOGGER.debug("deleting slash command %r from guild %r", cmd.name, str(cmd.guild_id))
+                        await cmd.delete()
+                    else:
+                        # We are assuming here that all the guild commands with the same name have the same
+                        # implementation so that we don't have to do a million more checks
+                        if cmd.name in remaining_guild_cmds:
+                            remaining_guild_cmds[cmd.name][1].append(cmd.guild_id)
+                        else:
+                            remaining_guild_cmds[cmd.name] = [cmd, [cmd.guild_id]]
+        else:
+            for cmd_name, cmds in guild_slash_commands.items():
+                for cmd, guild_id in cmds:
+                    if cmd.name in remaining_guild_cmds:
+                        remaining_guild_cmds[cmd.name][1].append(guild_id)
+                    else:
+                        remaining_guild_cmds[cmd.name] = [cmd, [guild_id]]
+
+        def compare_commands(
+            lb_cmd: typing.Union[slash_commands.SlashCommand, slash_commands.SlashCommandGroup],
+            hk_cmd: hikari.Command,
+            _guild_ids: typing.Optional[typing.List] = None,
+        ) -> bool:
+            # If one command is global and the other isn't
+            if (not lb_cmd.enabled_guilds and _guild_ids) or (lb_cmd.enabled_guilds and not _guild_ids):
+                return False
+
+            # If both commands are global
+            if _guild_ids is None and not lb_cmd.enabled_guilds:
+                return _serialise_command(lb_cmd) == _serialise_command(hk_cmd)
+
+            # If both commands are guild commands and for the same guilds
+            if set(lb_cmd.enabled_guilds) == set(_guild_ids):
+                return _serialise_command(lb_cmd) == _serialise_command(hk_cmd)
+
+            # None of the above
+            return False
+
+        # Check if existing slash commands have changed before creating any. If a command does not appear
+        # to have changed then we don't send the api request to discord to prevent unnecessary rate-limiting and
+        # to prevent the 1h wait period when creating global commands
+        if self._recreate_changed_slash_commands:
+            for cmd in remaining_globals.values():
+                if cmd.name not in self._slash_commands:
+                    continue
+
+                if not compare_commands(self._slash_commands[cmd.name], cmd):
+                    _LOGGER.debug("recreating global slash command %r as it appears to have changed", cmd.name)
+                    await self._slash_commands[cmd.name].auto_create(self._app)
+                else:
+                    _LOGGER.debug(
+                        "not recreating global slash command %r as it doesn't appear to have changed", cmd.name
+                    )
+
+            for cmd, guild_ids in remaining_guild_cmds.values():
+                if cmd.name not in self._slash_commands:
+                    continue
+
+                if not compare_commands(self._slash_commands[cmd.name], cmd, guild_ids):
+                    _LOGGER.debug("recreating guild slash command %r as it appears to have changed", cmd.name)
+                    await self._slash_commands[cmd.name].auto_create(self._app)
+                else:
+                    _LOGGER.debug(
+                        "not recreating guild slash command %r as it doesn't appear to have changed", cmd.name
+                    )
+
+        all_cmd_names = [
+            *[c.name for c in remaining_globals.values()],
+            *[c.name for c, _ in remaining_guild_cmds.values()],
+        ]
+        for cmd_name, cmd in self._slash_commands.items():
+            if cmd_name not in all_cmd_names:
+                _LOGGER.debug("creating slash command %r as it does not seem to exist yet", cmd_name)
+                await cmd.auto_create(self._app)
