@@ -46,6 +46,7 @@ from lightbulb.converters import _GreedyConverter
 from lightbulb.converters import _UnionConverter
 
 if typing.TYPE_CHECKING:
+    from lightbulb import checks as checks_
     from lightbulb import plugins
 
 _LOGGER = logging.getLogger("lightbulb")
@@ -238,7 +239,7 @@ class Command:
         self._allow_extra_arguments = allow_extra_arguments
         self._aliases = aliases
         self.hidden = hidden
-        self._checks = []
+        self._checks: typing.List[checks_.Check] = []
         self._check_exempt_predicate = lambda ctx: False
         self._raw_error_listener = None
         self._raw_before_invoke = None
@@ -246,8 +247,7 @@ class Command:
         self.method_name: typing.Optional[str] = None
         self.parent: typing.Optional[Group] = parent
         """The parent group for the command. If ``None`` then the command is not a subcommand."""
-        self.plugin: typing.Optional[plugins.Plugin] = None
-        """The plugin the command is registered to. If ``None`` then it was defined outside of a plugin."""
+        self._plugin: typing.Optional[plugins.Plugin] = None
         self.user_required_permissions: hikari.Permissions = hikari.Permissions.NONE
         """
         The permissions required by a user to run the command.
@@ -285,6 +285,15 @@ class Command:
     def __eq__(self, other) -> bool:
         return isinstance(other, type(self)) and other.name == self.name
 
+    @property
+    def plugin(self) -> typing.Optional[plugins.Plugin]:
+        """The plugin the command is registered to. If ``None`` then it was defined outside of a plugin."""
+        return self._plugin
+
+    @plugin.setter
+    def plugin(self, new_plugin: plugins.Plugin) -> None:
+        self._plugin = new_plugin
+
     @functools.cached_property
     def _error_listener(self):
         if self.plugin is not None and self._raw_error_listener is not None:
@@ -326,7 +335,7 @@ class Command:
     @property
     def qualified_name(self) -> str:
         """
-        The fully qualified name of the command, taking into  account
+        The fully qualified name of the command, taking into account
         whether or not the command is a subcommand.
 
         Returns:
@@ -463,7 +472,7 @@ class Command:
 
         return await self._callback(context, *args, **kwargs)
 
-    def add_check(self, check_func: typing.Callable[[context_.Context], typing.Coroutine[None, None, bool]]) -> None:
+    def add_check(self, check_func: checks_.Check) -> None:
         """
         Add a check to an instance of :obj:`~.commands.Command` or a subclass. The check passed must
         be an awaitable function taking a single argument which will be an instance of :obj:`~.context.Context`.
@@ -471,8 +480,7 @@ class Command:
         or raise an instance of :obj:`~.errors.CheckFailure` or a subclass.
 
         Args:
-            check_func (Callable[ [ :obj:`~.context.Context` ], Coroutine[ ``None``, ``None``, :obj:`bool` ] ]): Check
-                to add to the command
+            check_func (:obj:`~lightbulb.checks.Check`): Check to add to the command
 
         Returns:
             ``None``
@@ -484,11 +492,12 @@ class Command:
                 async def author_name_startswith_foo(ctx):
                     return ctx.author.username.startswith("foo")
 
-                bot.get_command("foo").add_check(author_name_startswith_foo)
+                bot.get_command("foo").add_check(Check(author_name_startswith_foo))
 
         See Also:
             :meth:`~.checks.check`
         """
+        check_func.add_to_command_hook(self)
         self._checks.append(check_func)
 
     async def is_runnable(self, context: context_.Context) -> bool:
@@ -542,6 +551,17 @@ class Group(Command):
         self.subcommands: typing.Set[Command] = set()
         """A set containing all subcommands registered to the group."""
 
+    @property
+    def plugin(self) -> typing.Optional[plugins.Plugin]:
+        """The plugin the command is registered to. If ``None`` then it was defined outside of a plugin."""
+        return self._plugin
+
+    @plugin.setter
+    def plugin(self, new_plugin: plugins.Plugin) -> None:
+        for subcommand in self._subcommands.values():
+            subcommand.plugin = new_plugin
+        self._plugin = new_plugin
+
     def _resolve_subcommand(self, args) -> typing.Tuple[typing.Union[Command, Group], typing.Iterable[str]]:
         this = self
 
@@ -569,7 +589,7 @@ class Group(Command):
             if isinstance(command, Group):
                 yield from command.walk_commands()
 
-    def add_check(self, check_func: typing.Callable[[context_.Context], typing.Coroutine[None, None, bool]]) -> None:
+    def add_check(self, check_func: checks_.Check) -> None:
         if self.inherit_checks:
             for c in self.subcommands:
                 c.add_check(check_func)
