@@ -40,7 +40,7 @@ class EventListenerDescriptor:
     """
     Descriptor for a listener.
 
-    This provides the same introspective logic as :meth:`hikari.BotApp.listen`, but
+    This provides the same introspective logic as :meth:`hikari.GatewayBot.listen`, but
     does so using a descriptor instead of directly subscribing the function. This
     is detected when loading plugins as a way of defining event listeners within
     plugins lazily.
@@ -171,7 +171,7 @@ class Plugin:
 
                 @lightbulb.command()
                 async def ping(self, ctx):
-                    await ctx.send("Pong!")
+                    await ctx.respond("Pong!")
 
             bot.add_plugin(MyPlugin())
     """
@@ -180,7 +180,7 @@ class Plugin:
         self.name = self.__class__.__name__ if name is None else name
         """The plugin's registered name."""
         self.commands = set()
-        """"A set containing all commands and groups registered to the plugin."""
+        """A set containing all commands and groups registered to the plugin."""
         self._commands: typing.MutableMapping[str, typing.Union[commands.Command, commands.Group]] = {}
         self.listeners: typing.MutableMapping[
             typing.Type[hikari.Event],
